@@ -1,7 +1,7 @@
 package App::lcpan;
 
-our $DATE = '2015-02-24'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2015-02-25'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -47,6 +47,11 @@ Defaults to C<~/cpan>.
 _
         tags => ['common'],
     },
+    index_name => {
+        summary => 'Filename of index',
+        schema  => 'str*',
+        default => 'index.db',
+    },
 );
 
 $SPEC{':package'} = {
@@ -60,6 +65,7 @@ sub _set_args_default {
         require File::HomeDir;
         $args->{cpan} = File::HomeDir->my_home . '/cpan';
     }
+    $args->{index_name} //= 'index.db';
     if (!defined($args->{num_backups})) {
         $args->{num_backups} = 7;
     }
@@ -187,17 +193,22 @@ sub _create_schema {
 }
 
 sub _db_path {
-    my $cpan = shift;
-    "$cpan/index.db";
+    my ($cpan, $index_name) = @_;
+    "$cpan/$index_name";
 }
 
 sub _connect_db {
     require DBI;
 
-    my $cpan = shift;
+    my ($mode, $cpan, $index_name) = @_;
 
-    my $db_path = _db_path($cpan);
+    my $db_path = _db_path($cpan, $index_name);
     $log->tracef("Connecting to SQLite database at %s ...", $db_path);
+    if ($mode eq 'ro') {
+        # avoid creating the index file automatically if we are only in
+        # read-only mode
+        die "Can't find index '$db_path'\n" unless -f $db_path;
+    }
     my $dbh = DBI->connect("dbi:SQLite:dbname=$db_path", undef, undef,
                            {RaiseError=>1});
     _create_schema($dbh);
@@ -287,6 +298,7 @@ sub update_local_cpan_files {
     my %args = @_;
     _set_args_default(\%args);
     my $cpan = $args{cpan};
+    my $index_name = $args{index_name};
     my $remote_url = $args{remote_url} // "http://mirrors.kernel.org/cpan";
     my $max_file_size = $args{max_file_size};
 
@@ -300,7 +312,7 @@ sub update_local_cpan_files {
         @cmd,
     );
 
-    my $dbh = _connect_db($cpan);
+    my $dbh = _connect_db('rw', $cpan, $index_name);
     $dbh->do("INSERT OR REPLACE INTO meta (name,value) VALUES (?,?)",
              {}, 'last_mirror_time', time());
 
@@ -362,8 +374,9 @@ sub update_local_cpan_index {
     my %args = @_;
     _set_args_default(\%args);
     my $cpan = $args{cpan};
+    my $index_name = $args{index_name};
 
-    my $db_path = _db_path($cpan);
+    my $db_path = _db_path($cpan, $index_name);
     if ($args{num_backups} > 0 && (-f $db_path)) {
         require File::Copy;
         require Logfile::Rotate;
@@ -378,7 +391,7 @@ sub update_local_cpan_index {
               or return [500, "Copy $db_path.1 -> $db_path failed: $!"];
     }
 
-    my $dbh  = _connect_db($cpan);
+    my $dbh  = _connect_db('rw', $cpan, $index_name);
 
     # parse 01mailrc.txt.gz and insert the parse result to 'author' table
     {
@@ -723,7 +736,8 @@ sub stat_local_cpan {
     my %args = @_;
     _set_args_default(\%args);
     my $cpan = $args{cpan};
-    my $dbh = _connect_db($cpan);
+    my $index_name = $args{index_name};
+    my $dbh = _connect_db('ro', $cpan, $index_name);
 
     my $stat = {};
 
@@ -767,7 +781,7 @@ sub _complete_mod {
     _set_args_default($res->[2]);
 
     my $dbh;
-    eval { $dbh = _connect_db($res->[2]{cpan}) };
+    eval { $dbh = _connect_db('ro', $res->[2]{cpan}, $res->[2]{index_name}) };
 
     # if we can't connect (probably because database is not yet setup), bail
     if ($@) {
@@ -811,7 +825,7 @@ sub _complete_dist {
     _set_args_default($res->[2]);
 
     my $dbh;
-    eval { $dbh = _connect_db($res->[2]{cpan}) };
+    eval { $dbh = _connect_db('ro', $res->[2]{cpan}, $res->[2]{index_name}) };
 
     # if we can't connect (probably because database is not yet setup), bail
     if ($@) {
@@ -855,7 +869,7 @@ sub _complete_cpanid {
     _set_args_default($res->[2]);
 
     my $dbh;
-    eval { $dbh = _connect_db($res->[2]{cpan}) };
+    eval { $dbh = _connect_db('ro', $res->[2]{cpan}, $res->[2]{index_name}) };
 
     # if we can't connect (probably because database is not yet setup), bail
     if ($@) {
@@ -942,11 +956,12 @@ sub list_local_cpan_authors {
 
     _set_args_default(\%args);
     my $cpan = $args{cpan};
+    my $index_name = $args{index_name};
     my $detail = $args{detail};
     my $q = $args{query} // ''; # sqlite is case-insensitive by default, yay
     $q = '%'.$q.'%' unless $q =~ /%/;
 
-    my $dbh = _connect_db($cpan);
+    my $dbh = _connect_db('ro', $cpan, $index_name);
 
     my @bind;
     my @where;
@@ -995,12 +1010,13 @@ sub list_local_cpan_packages {
 
     _set_args_default(\%args);
     my $cpan = $args{cpan};
+    my $index_name = $args{index_name};
     my $detail = $args{detail};
     my $q = $args{query} // ''; # sqlite is case-insensitive by default, yay
     $q = '%'.$q.'%' unless $q =~ /%/;
     my $author = uc($args{author} // '');
 
-    my $dbh = _connect_db($cpan);
+    my $dbh = _connect_db('ro', $cpan, $index_name);
 
     my @bind;
     my @where;
@@ -1092,12 +1108,13 @@ sub list_local_cpan_dists {
 
     _set_args_default(\%args);
     my $cpan = $args{cpan};
+    my $index_name = $args{index_name};
     my $detail = $args{detail};
     my $q = $args{query} // '';
     $q = '%'.$q.'%' unless $q =~ /%/;
     my $author = uc($args{author} // '');
 
-    my $dbh = _connect_db($cpan);
+    my $dbh = _connect_db('ro', $cpan, $index_name);
 
     my @bind;
     my @where;
@@ -1159,12 +1176,13 @@ sub list_local_cpan_releases {
 
     _set_args_default(\%args);
     my $cpan = $args{cpan};
+    my $index_name = $args{index_name};
     my $detail = $args{detail};
     my $q = $args{query} // ''; # sqlite is case-insensitive by default, yay
     $q = '%'.$q.'%' unless $q =~ /%/;
     my $author = uc($args{author} // '');
 
-    my $dbh = _connect_db($cpan);
+    my $dbh = _connect_db('ro', $cpan, $index_name);
 
     my @bind;
     my @where;
@@ -1247,9 +1265,10 @@ sub mod2dist {
 
     _set_args_default(\%args);
     my $cpan = $args{cpan};
+    my $index_name = $args{index_name};
     my $mod = $args{module};
 
-    my $dbh = _connect_db($cpan);
+    my $dbh = _connect_db('ro', $cpan, $index_name);
 
     my ($res) = $dbh->selectrow_array("SELECT dist.name
 FROM module
@@ -1275,9 +1294,10 @@ sub mod2rel {
 
     _set_args_default(\%args);
     my $cpan = $args{cpan};
+    my $index_name = $args{index_name};
     my $mod = $args{module};
 
-    my $dbh = _connect_db($cpan);
+    my $dbh = _connect_db('ro', $cpan, $index_name);
 
     my $row = $dbh->selectrow_hashref("SELECT
   file.cpanid cpanid,
@@ -1320,9 +1340,10 @@ sub dist2rel {
 
     _set_args_default(\%args);
     my $cpan = $args{cpan};
+    my $index_name = $args{index_name};
     my $dist = $args{dist};
 
-    my $dbh = _connect_db($cpan);
+    my $dbh = _connect_db('ro', $cpan, $index_name);
 
     my $row = $dbh->selectrow_hashref("SELECT
   file.cpanid cpanid,
@@ -1353,9 +1374,10 @@ sub distmods {
 
     _set_args_default(\%args);
     my $cpan = $args{cpan};
+    my $index_name = $args{index_name};
     my $dist = $args{dist};
 
-    my $dbh = _connect_db($cpan);
+    my $dbh = _connect_db('ro', $cpan, $index_name);
 
     my $sth = $dbh->prepare("SELECT
   module.name name,
@@ -1613,6 +1635,7 @@ sub list_local_cpan_deps {
 
     _set_args_default(\%args);
     my $cpan = $args{cpan};
+    my $index_name = $args{index_name};
     my $mod     = $args{module};
     my $phase   = $args{phase} // 'runtime';
     my $rel     = $args{rel} // 'requires';
@@ -1620,7 +1643,7 @@ sub list_local_cpan_deps {
     my $level   = $args{level} // 1;
     my $include_core = $args{include_core} // 0;
 
-    my $dbh     = _connect_db($cpan);
+    my $dbh     = _connect_db('ro', $cpan, $index_name);
 
     my $res = _get_prereqs($mod, $dbh, {}, 1, $level, $phase, $rel, $include_core, $plver);
 
@@ -1668,11 +1691,12 @@ sub list_local_cpan_rev_deps {
 
     _set_args_default(\%args);
     my $cpan = $args{cpan};
+    my $index_name = $args{index_name};
     my $mod     = $args{module};
     my $author =  $args{author} ? [map {uc} @{$args{author}}] : undef;
     my $author_isnt = $args{author_isnt} ? [map {uc} @{$args{author_isnt}}] : undef;
 
-    my $dbh     = _connect_db($cpan);
+    my $dbh     = _connect_db('ro', $cpan, $index_name);
 
     my $filters = {
         author => $author,
@@ -1697,7 +1721,7 @@ App::lcpan - Manage your local CPAN mirror
 
 =head1 VERSION
 
-This document describes version 0.11 of App::lcpan (from Perl distribution App-lcpan), released on 2015-02-24.
+This document describes version 0.12 of App::lcpan (from Perl distribution App-lcpan), released on 2015-02-25.
 
 =head1 SYNOPSIS
 
@@ -1722,6 +1746,10 @@ Location of your local CPAN mirror, e.g. /path/to/cpan.
 
 Defaults to C<~/cpan>.
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =item * B<latest> => I<bool>
 
 =back
@@ -1745,6 +1773,10 @@ Location of your local CPAN mirror, e.g. /path/to/cpan.
 
 Defaults to C<~/cpan>.
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =back
 
 Return value:  (any)
@@ -1768,6 +1800,10 @@ Defaults to C<~/cpan>.
 
 =item * B<full_path> => I<bool>
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =item * B<latest> => I<bool>
 
 =back
@@ -1793,6 +1829,10 @@ Defaults to C<~/cpan>.
 
 =item * B<full_path> => I<bool>
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =back
 
 Return value:  (any)
@@ -1814,6 +1854,10 @@ Defaults to C<~/cpan>.
 
 =item * B<dist>* => I<str>
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =back
 
 Return value:  (any)
@@ -1849,6 +1893,10 @@ Defaults to C<~/cpan>.
 
 =item * B<detail> => I<bool>
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =item * B<query> => I<str>
 
 Search query.
@@ -1892,6 +1940,10 @@ Defaults to C<~/cpan>.
 
 Include Perl core modules.
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =item * B<level> => I<int> (default: 1)
 
 Recurse for a number of levels (-1 means unlimited).
@@ -1960,6 +2012,10 @@ Defaults to C<~/cpan>.
 
 =item * B<detail> => I<bool>
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =item * B<latest> => I<bool>
 
 =item * B<query> => I<str>
@@ -1999,6 +2055,10 @@ Defaults to C<~/cpan>.
 
 Filter by distribution.
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =item * B<query> => I<str>
 
 Search query.
@@ -2036,6 +2096,10 @@ Defaults to C<~/cpan>.
 
 Filter by distribution.
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =item * B<query> => I<str>
 
 Search query.
@@ -2079,6 +2143,10 @@ Defaults to C<~/cpan>.
 
 =item * B<has_metayml> => I<bool>
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =item * B<latest> => I<bool>
 
 =item * B<query> => I<str>
@@ -2118,6 +2186,10 @@ Location of your local CPAN mirror, e.g. /path/to/cpan.
 
 Defaults to C<~/cpan>.
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =item * B<module>* => I<str>
 
 =back
@@ -2148,6 +2220,10 @@ Location of your local CPAN mirror, e.g. /path/to/cpan.
 
 Defaults to C<~/cpan>.
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =item * B<module>* => I<str>
 
 =back
@@ -2171,6 +2247,10 @@ Defaults to C<~/cpan>.
 
 =item * B<full_path> => I<bool>
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =item * B<module>* => I<str>
 
 =back
@@ -2192,6 +2272,10 @@ Location of your local CPAN mirror, e.g. /path/to/cpan.
 
 Defaults to C<~/cpan>.
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =back
 
 Returns an enveloped result (an array).
@@ -2222,6 +2306,10 @@ Location of your local CPAN mirror, e.g. /path/to/cpan.
 
 Defaults to C<~/cpan>.
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =back
 
 Returns an enveloped result (an array).
@@ -2255,6 +2343,10 @@ Location of your local CPAN mirror, e.g. /path/to/cpan.
 
 Defaults to C<~/cpan>.
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =item * B<max_file_size> => I<int>
 
 If set, skip downloading files larger than this.
@@ -2303,6 +2395,10 @@ Location of your local CPAN mirror, e.g. /path/to/cpan.
 
 Defaults to C<~/cpan>.
 
+=item * B<index_name> => I<str> (default: "index.db")
+
+Filename of index.
+
 =item * B<num_backups> => I<int> (default: 7)
 
 Keep a number of backups.
